# Fractal Server

[![PyPI version](https://img.shields.io/pypi/v/fractal-server?color=gree)](https://pypi.org/project/fractal-server/)
[![CI Status](https://github.com/fractal-analytics-platform/fractal-server/actions/workflows/ci.yml/badge.svg)](https://github.com/fractal-analytics-platform/fractal-server/actions/workflows/ci.yml)
[![Coverage](https://raw.githubusercontent.com/fractal-analytics-platform/fractal-server/python-coverage-comment-action-data/badge.svg)](https://htmlpreview.github.io/?https://github.com/fractal-analytics-platform/fractal-server/blob/python-coverage-comment-action-data/htmlcov/index.html)
[![License](https://img.shields.io/badge/License-BSD_3--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)

Fractal is a framework to process high content imaging data at scale and
prepare it for interactive visualization.

![Fractal_Overview](https://fractal-analytics-platform.github.io/assets/fractal_overview.jpg)

This is the server component of the fractal analytics platform.
Find more information about Fractal in general and the other repositories at
the [Fractal home page](https://fractal-analytics-platform.github.io).


## Documentation

See https://fractal-analytics-platform.github.io/fractal-server.

# Contributors and license

Unless otherwise stated in each individual module, all Fractal components are
released according to a BSD 3-Clause License, and Copyright is with Friedrich
Miescher Institute for Biomedical Research and University of Zurich.

The SLURM compatibility layer is based on
[`clusterfutures`](https://github.com/sampsyo/clusterfutures), by
[@sampsyo](https://github.com/sampsyo) and collaborators, and it is released
under the terms of the MIT license.

Fractal was conceived in the Liberali Lab at the Friedrich Miescher Institute
for Biomedical Research and in the Pelkmans Lab at the University of Zurich
(both in Switzerland). The project lead is with
[@gusqgm](https://github.com/gusqgm) & [@jluethi](https://github.com/jluethi).
The core development is done under contract by [eXact lab S.r.l.](https://exact-lab.it).
